# 领域专用语言

领域专用语言（[Domain Specified Language](https://www.jetbrains.com/zh-cn/mps/concepts/domain-specific-languages/)，简称 DSL）是一种针对特定类问题优化，包含更高级抽象的编程语言。DSL 使用来自专业或领域的概念和规则。

[元编程](https://www.jianshu.com/p/d3b637ece518)。
